/**
 * NASR - Noise-Adaptive Shape Reconstruction
 * Source code, Version 1.0 (December 2014)
 *
 * Copyright (c) 2014 Simon Giraudot <simon.giraudot@inria.fr>
 * http://www-sop.inria.fr/members/Simon.Giraudot/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef __COMMON__
#define __COMMON__

#include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
#include <CGAL/Delaunay_triangulation_cell_base_with_circumcenter_3.h>
#include <CGAL/bounding_box.h>
#include <CGAL/centroid.h>
#include <CGAL/convex_hull_3.h>
#include <CGAL/Polyhedron_3.h>

// kernel
typedef CGAL::Exact_predicates_inexact_constructions_kernel Kernel;

// basic types from kernel
typedef CGAL::Bbox_3 Bbox;
typedef Kernel::FT FT;
typedef Kernel::Point_3 Point;
typedef Kernel::Sphere_3 Sphere;
typedef Kernel::Vector_3 Vector;
typedef Kernel::Line_3 Line;
typedef Kernel::Segment_3 Segment;
typedef Kernel::Triangle_3 Triangle;
typedef Kernel::Plane_3 Plane;
typedef Kernel::Iso_cuboid_3 Iso_cuboid; 
typedef CGAL::Polyhedron_3<Kernel> Polyhedron;

// useful typedefs
#include <vector>
typedef std::vector<Point> Point_set;

#include "utils.h"

// Neighbor search
#include "neighbor_search.h"
typedef CNeighbor_search<Kernel> Neighbor_search;

// Delaunay triangulation
#include "dt.h"
typedef My_cell_base<Kernel,CGAL::Delaunay_triangulation_cell_base_with_circumcenter_3<Kernel> > Cb;
typedef My_vertex_base<Kernel> Vb;
typedef CGAL::Triangulation_data_structure_3<Vb,Cb> Tds;
typedef DT3<Kernel,Tds> Dt3;

// Graph
#include "graph.h"
typedef CNode<Kernel> Node;
typedef CGraph<Kernel, Dt3> Graph;

// Mesh
#include "mesh.h"
typedef CMesh<Kernel, Dt3> Mesh;


#endif // COMMON__


