/**
 * NASR - Noise-Adaptive Shape Reconstruction
 * Source code, Version 1.0 (December 2014)
 *
 * Copyright (c) 2014 Simon Giraudot <simon.giraudot@inria.fr>
 * http://www-sop.inria.fr/members/Simon.Giraudot/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef __IO_WRAPPER__
#define __IO_WRAPPER__

#include <iostream>
#include <fstream>
#include <string>

#include <CGAL/IO/Complex_2_in_triangulation_3_file_writer.h>
#include <CGAL/IO/read_off_points.h>
#include <CGAL/IO/read_xyz_points.h>


#include "common.h"
#include "mesh.h"

class IO_wrapper
{

private:

public:

  IO_wrapper () { }
  virtual ~IO_wrapper () { }

  void read_point_set (const std::string& filename,
		       Point_set& point_set)
  {
    std::ifstream f (filename.c_str ());
    if (!(f.is_open ()))
      Utils::error ("Cannot open input file.");

    std::string xyz (".xyz");
    std::string off (".off");
    if (filename.find (xyz) != std::string::npos)
      read_xyz (f, point_set);
    else if (filename.find (off) != std::string::npos)
      read_off (f, point_set);
    else
      {
	f.close ();
	Utils::error ("Unknown input file format.");
      }

    f.close ();
  }

  void read_xyz (std::ifstream& f, Point_set& point_set)
  {
    if (!CGAL::read_xyz_points (f, std::back_inserter (point_set)))
      Utils::error ("Cannot read input file.");
  }

  void read_off (std::ifstream& f, Point_set& point_set)
  {
    if (!CGAL::read_off_points (f, std::back_inserter (point_set)))
      Utils::error ("Cannot read input file.");
  }

  void write_surface (const std::string& filename, const Mesh& mesh)
  {
    std::ofstream f (filename.c_str ());
    if (!(f.is_open ()))
      Utils::error ("Cannot write output file.");

    CGAL::output_surface_facets_to_off (f, mesh.get ());

    f.close ();
  }

};



#endif // IO_WRAPPER__
