/**
 * NASR - Noise-Adaptive Shape Reconstruction
 * Source code, Version 1.0 (December 2014)
 *
 * Copyright (c) 2014 Simon Giraudot <simon.giraudot@inria.fr>
 * http://www-sop.inria.fr/members/Simon.Giraudot/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __UTILS__
#define __UTILS__

#include <cmath>

namespace Utils
{
  inline void error (const char* msg)
  {
    std::cerr << "ERROR: " << msg << " Exiting." << std::endl;
    exit (EXIT_FAILURE);
  }

  inline void print (const char* msg)
  {
    std::cout << msg << std::endl;
  }

  inline void print (const bool verbose, const char* msg)
  {
    if (verbose)
      std::cout << msg << std::endl;
  }

  template <typename T>
  inline T square (const T& t)
  {
    return t*t;
  }

  template <typename T>
  inline T cbrt (const T& t)
  {
    return std::pow (t, 1./3.);
  }

  inline void display_time (time_t seconds)
  {
    if (seconds > 3600.)
      {
	int hours = (int)(seconds / 3600.);
	std::cerr << hours << "h ";
	seconds -= hours * 3600.;
      }
    if (seconds > 60.)
      {
	int minutes = (int)(seconds / 60.);
	std::cerr << minutes << "min ";
	seconds -= minutes * 60.;
      }
    std::cerr << seconds << "sec";
  }

  inline void display_progress (const int step,
				const int total,
				const time_t starting_time)
  {
    const double frac_done = (step + 1) / (double)total;
    const time_t spent_time = time (NULL) - starting_time;
    const time_t remaining_time
      = (time_t)((1./frac_done - 1.) * (double)spent_time);

    std::cerr << "\r" << 100. * frac_done << "% done in ";
    display_time (spent_time);
    std::cerr << " (";
    display_time (remaining_time);
    std::cerr << " remaining)";

  }

  inline bool is_bit_set (const int x, const int position)
  {
    return (x & (1 << position));
  }

}

#endif // UTILS__
